@@ -1,4 +1,4 @@
-mdae = function(forecast, true)
+mdae <- function(forecast, true)
 {
     if (length(forecast) != length(true))
         stop("MDAE: the lengths of input vectors must be the same.")
